==> tmaid-2.2.2.tar.gz: tmaid-2.2.2/src/toolbar.c <==
/*
    Text maid
    copyright (c) 1998-2002 Iwamoto,Kazuki http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#include "command.h"
#include "toolbar.h"


/******************************************************************************
*                                                                             *
* ġСؿ                                                            *
*                                                                             *
******************************************************************************/
/* XPM */
static gchar *tb_new_xpm[]={
"16 16 4 1",
" 	c None",
".	c #000000",
"+	c #FF0000",
"@	c #FFFFFF",
"          +     ",
" ......+..+..+  ",
" .@@@@@@+@+@+   ",
" .@@@@@@@+++.   ",
" .@@@@+++++++++ ",
" .@@@@@@@+++.   ",
" .@@@@@@+@+@+   ",
" .@@@@@+@@+@.+  ",
" .@@@@@@@@+@.   ",
" .@@@@@@@@@@.   ",
" .@@@@@@@@@@.   ",
" .@@@@@@@@@@.   ",
" .@@@@@@@@@@.   ",
" .@@@@@@@@@@.   ",
" ............   ",
"                "};


/* XPM */
static gchar *tb_open_xpm[]={
"16 16 5 1",
" 	c None",
".	c #000000",
"=	c #808080",
">	c #FFFF00",
"!	c #FFFFFF",
"  ......        ",
" .!>!>!>.       ",
".!>!>!>!>.......",
".>!>!>!>!>!>!>!.",
".!============>.",
".>=!!!!!!!!!!=!.",
".!=!!!!!!.......",
".>=!!!!!.>!>!>!.",
"........>!>!>!>.",
".>!>!>!>!>!>!>!.",
".!>!>!>!>!>!>!>.",
".>!>!>!>!>!>!>!.",
".!>!>!>!>!>!>!>.",
".>!>!>!>!>!>!>!.",
".!>!>!>!>!>!>!>.",
"................"};


/* XPM */
static gchar *tb_save_xpm[]={
"16 16 5 1",
"  c None",
". c #000000",
"+ c #808000",
"@ c #808080",
"# c #CCCCCC",
"                ",
" .............. ",
" .@@####@@##@@. ",
" .@@####@@##@@. ",
" .@@####@@##@@. ",
" .@@########@@. ",
" .@@@@@@@@@@@@. ",
" .@..........@. ",
" .@.++++++++.@. ",
" .@.++++++++.@. ",
" .@.++++++++.@. ",
" .@.++++++++.@. ",
" .@.++++++++.@. ",
" .@.++++++++.@. ",
" .............. ",
"                "};


static gchar *tb_prop_xpm[]={
"16 16 4 1",
"  c None",
". c #000000",
"+ c #808080",
"@ c #FFFFFF",
"                ",
"  ............  ",
"  .@@@@@@@@@@.  ",
"  .@+++@@@@@@.  ",
"  .@@@@@@@@@@.  ",
"  .@@@@@@@@@@.  ",
"  .@++++++++@.  ",
"  .@@@@@@@@@@.  ",
"  .@++++++++@.  ",
"  .@@@@@@@@@@.  ",
"  .@++++++++@.  ",
"  .@@@@@@@@@@.  ",
"  .@@@@@++++@.  ",
"  .@@@@@@@@@@.  ",
"  ............  ",
"                "};


static gchar *tb_print_xpm[]={
"16 16 7 1",
" 	c None",
".	c #000000",
"#	c #808000",
"*	c #C0C0C0",
"=	c #808080",
";	c #00FF00",
"!	c #FFFFFF",
"     .......... ",
"     .!!!!!!!!. ",
"     .!*****!!. ",
"    .!!!!!!!!.  ",
"    .!******!.  ",
"    .!!!!!!!!.  ",
"   .!!*****!.   ",
"   .!!!!!!!!... ",
"  .==========#..",
" .###########.#.",
" ............##.",
".###########.##.",
".#######;;;#.##.",
".###########.#. ",
".###########..  ",
" ...........    "};


/* XPM */
static gchar *tb_cut_xpm[]={
"16 16 5 1",
" 	c None",
".	c #000000",
"-	c #FF0000",
",	c #0000FF",
"!	c #FFFFFF",
"                ",
"....         ,, ",
"!!!.        ,  ,",
"......,,    ,  ,",
".!!!!.,,,    ,, ",
".!!!!.  ,,,,,   ",
".!!!!.,,,, ,,   ",
".!!,,,,,    ,,, ",
".,,,,,     ,   ,",
".!!!!.     ,   ,",
"......      ,,, ",
"-   -           ",
"--  --          ",
" ------         ",
"    --          ",
"    -           "};


/* XPM */
static gchar *tb_copy_xpm[]={
"16 16 4 1",
" 	c None",
".	c #000000",
"-	c #FF0000",
"!	c #FFFFFF",
"    .........   ",
"    .!!!!!!!.   ",
"    .!!!!!!!.   ",
"    .!!.........",
"    .!!.!!!!!!!.",
"    .!!.!!!!!!!.",
"    .!!.!!!!!!!.",
"    .!!.!!!!!!!.",
"-   .!!.!!!!!!!.",
"-   .!!.!!!!!!!.",
"-   ....!!!!!!!.",
"-  -   .!!!!!!!.",
"-- --  .!!!!!!!.",
" ----- .........",
"   --           ",
"   -            "};


/* XPM */
static gchar *tb_paste_xpm[]={
"16 16 5 1",
" 	c None",
".	c #000000",
"*	c #C0C0C0",
"=	c #808080",
"!	c #FFFFFF",
"                ",
"     .........  ",
"     .!!!!!!!.  ",
"     .!!!!!!!.  ",
"  ....!!!!!!!.  ",
"  .!!=!!!!!!!.  ",
"  .!!=!!!!!!!.  ",
"  .!!=====!!!.  ",
"  .!!!*!!=!!!.  ",
"  .!!!!*!=!!!.  ",
"  .!!!!!*=!!!.  ",
"  .!!!!!!=....  ",
"  .!!!!!!!.     ",
"  .!!!!!!!.     ",
"  .........     ",
"                "};


/* XPM */
static gchar *tb_delete_xpm[]={
"16 16 2 1",
" 	c None",
",	c #0000FF",
"                ",
"                ",
"                ",
"             ,, ",
" ,,,,       ,  ,",
"   ,,,,,    ,  ,",
"     ,,,,    ,, ",
"        ,,,,,   ",
"      ,,,, ,,   ",
"   ,,,,,    ,,, ",
" ,,,,,     ,   ,",
"           ,   ,",
"            ,,, ",
"                ",
"                ",
"                "};


/* XPM */
static gchar *tb_undo_xpm[]={
"16 16 2 1",
" 	c None",
"-	c #FF0000",
"                ",
"      ---       ",
"    -------     ",
"   ---   ---    ",
"   --     --    ",
"  --       --   ",
"  --       --   ",
"  --       --   ",
"  --       --   ",
"  --       --   ",
"  --       --   ",
"  --       --   ",
"  --     ------ ",
"  --      ----  ",
"  --       --   ",
"  --            "};


/* XPM */
static gchar *tb_redo_xpm[]={
"16 16 2 1",
" 	c None",
",	c #0000FF",
"            ,,  ",
"   ,,       ,,  ",
"  ,,,,      ,,  ",
" ,,,,,,     ,,  ",
"   ,,       ,,  ",
"   ,,       ,,  ",
"   ,,       ,,  ",
"   ,,       ,,  ",
"   ,,       ,,  ",
"   ,,       ,,  ",
"   ,,       ,,  ",
"    ,,     ,,   ",
"    ,,,   ,,,   ",
"     ,,,,,,,    ",
"       ,,,      ",
"                "};


/* XPM */
static gchar *tb_find_xpm[]={
"16 16 5 1",
" 	c None",
".	c #000000",
"$	c #000080",
",	c #0000FF",
"!	c #FFFFFF",
"         ....   ",
"        .    .  ",
"       .    !!. ",
"      .      !!.",
"      .       !.",
"      .       !.",
"      .        .",
"      ,.      . ",
"     ,,$.    .  ",
"    ,,$!,....   ",
"   ,,$!,        ",
"  ,,$!,         ",
" ,,$!,          ",
",,$!,           ",
" $!,            ",
"  ,             "};


/* XPM */
static gchar *tb_replace_xpm[]={
"16 16 5 1",
" 	c None",
".	c #000000",
"-	c #FF0000",
",	c #0000FF",
"!	c #FFFFFF",
"                ",
"   -----        ",
"       --       ",
"  -     -       ",
" ---  -----     ",
"-----  ---      ",
"  -     -  ...  ",
"  --      .   . ",
"   ----- .   !!.",
"         .    !.",
"         .     .",
"         ,.   . ",
"        ,,,...  ",
"       ,,,      ",
"      ,,,       ",
"       ,        "};


TOOLBAR toolbar_items[]={
/*  0 */ {N_("New"),       tb_new_xpm,    command_new,     NULL,NULL},
/*  1 */ {N_("Open"),      tb_open_xpm,   command_open,    NULL,NULL},
/*  2 */ {N_("Save"),      tb_save_xpm,   command_save,    NULL,NULL},
/*  3 */ {NULL,            NULL,          NULL,            NULL,NULL},
/*  4 */ {N_("Properties"),tb_prop_xpm,   command_property,NULL,NULL},
/*  5 */ {NULL,            NULL,          NULL,            NULL,NULL},
#ifdef USE_GDKPIXBUF
/*  6 */ {N_("Print"),     tb_print_xpm,  command_print,   NULL,NULL},
/*  7 */ {NULL,            NULL,          NULL,            NULL,NULL},
#endif
/*  8 */ {N_("Cut"),       tb_cut_xpm,    command_cut,     NULL,NULL},
/*  9 */ {N_("Copy"),      tb_copy_xpm,   command_copy,    NULL,NULL},
/* 10 */ {N_("Paste"),     tb_paste_xpm,  command_paste,   NULL,NULL},
/* 11 */ {N_("Delete"),    tb_delete_xpm, command_delete,  NULL,NULL},
/* 12 */ {NULL,            NULL,          NULL,            NULL,NULL},
/* 13 */ {N_("Undo"),      tb_undo_xpm,   command_undo,    NULL,NULL},
/* 14 */ {N_("Redo"),      tb_redo_xpm,   command_redo,    NULL,NULL},
/* 15 */ {NULL,            NULL,          NULL,            NULL,NULL},
/* 16 */ {N_("Find"),      tb_find_xpm,   command_find,    NULL,NULL},
/* 17 */ {N_("Replace"),   tb_replace_xpm,command_replace, NULL,NULL},
/* 18 */ {(gpointer)-1,    NULL,          NULL,            NULL,NULL}};

==> tmaid-2.2.6.tar.gz: tmaid-2.2.6/src/toolbar.c <==
/*
    Text maid
    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#include "command.h"
#include "toolbar.h"


/******************************************************************************
*                                                                             *
* ġСؿ                                                            *
*                                                                             *
******************************************************************************/
/* XPM */
static gchar *tb_new_xpm[]={
"16 16 4 1",
" 	c None",
".	c #000000",
"+	c #FF0000",
"@	c #FFFFFF",
"          +     ",
" ......+..+..+  ",
" .@@@@@@+@+@+   ",
" .@@@@@@@+++.   ",
" .@@@@+++++++++ ",
" .@@@@@@@+++.   ",
" .@@@@@@+@+@+   ",
" .@@@@@+@@+@.+  ",
" .@@@@@@@@+@.   ",
" .@@@@@@@@@@.   ",
" .@@@@@@@@@@.   ",
" .@@@@@@@@@@.   ",
" .@@@@@@@@@@.   ",
" .@@@@@@@@@@.   ",
" ............   ",
"                "};


/* XPM */
static gchar *tb_open_xpm[]={
"16 16 5 1",
" 	c None",
".	c #000000",
"=	c #808080",
">	c #FFFF00",
"!	c #FFFFFF",
"  ......        ",
" .!>!>!>.       ",
".!>!>!>!>.......",
".>!>!>!>!>!>!>!.",
".!============>.",
".>=!!!!!!!!!!=!.",
".!=!!!!!!.......",
".>=!!!!!.>!>!>!.",
"........>!>!>!>.",
".>!>!>!>!>!>!>!.",
".!>!>!>!>!>!>!>.",
".>!>!>!>!>!>!>!.",
".!>!>!>!>!>!>!>.",
".>!>!>!>!>!>!>!.",
".!>!>!>!>!>!>!>.",
"................"};


/* XPM */
static gchar *tb_save_xpm[]={
"16 16 5 1",
"  c None",
". c #000000",
"+ c #808000",
"@ c #808080",
"# c #CCCCCC",
"                ",
" .............. ",
" .@@####@@##@@. ",
" .@@####@@##@@. ",
" .@@####@@##@@. ",
" .@@########@@. ",
" .@@@@@@@@@@@@. ",
" .@..........@. ",
" .@.++++++++.@. ",
" .@.++++++++.@. ",
" .@.++++++++.@. ",
" .@.++++++++.@. ",
" .@.++++++++.@. ",
" .@.++++++++.@. ",
" .............. ",
"                "};


static gchar *tb_prop_xpm[]={
"16 16 4 1",
"  c None",
". c #000000",
"+ c #808080",
"@ c #FFFFFF",
"                ",
"  ............  ",
"  .@@@@@@@@@@.  ",
"  .@+++@@@@@@.  ",
"  .@@@@@@@@@@.  ",
"  .@@@@@@@@@@.  ",
"  .@++++++++@.  ",
"  .@@@@@@@@@@.  ",
"  .@++++++++@.  ",
"  .@@@@@@@@@@.  ",
"  .@++++++++@.  ",
"  .@@@@@@@@@@.  ",
"  .@@@@@++++@.  ",
"  .@@@@@@@@@@.  ",
"  ............  ",
"                "};


static gchar *tb_print_xpm[]={
"16 16 7 1",
" 	c None",
".	c #000000",
"#	c #808000",
"*	c #C0C0C0",
"=	c #808080",
";	c #00FF00",
"!	c #FFFFFF",
"     .......... ",
"     .!!!!!!!!. ",
"     .!*****!!. ",
"    .!!!!!!!!.  ",
"    .!******!.  ",
"    .!!!!!!!!.  ",
"   .!!*****!.   ",
"   .!!!!!!!!... ",
"  .==========#..",
" .###########.#.",
" ............##.",
".###########.##.",
".#######;;;#.##.",
".###########.#. ",
".###########..  ",
" ...........    "};


/* XPM */
static gchar *tb_cut_xpm[]={
"16 16 5 1",
" 	c None",
".	c #000000",
"-	c #FF0000",
",	c #0000FF",
"!	c #FFFFFF",
"                ",
"....         ,, ",
"!!!.        ,  ,",
"......,,    ,  ,",
".!!!!.,,,    ,, ",
".!!!!.  ,,,,,   ",
".!!!!.,,,, ,,   ",
".!!,,,,,    ,,, ",
".,,,,,     ,   ,",
".!!!!.     ,   ,",
"......      ,,, ",
"-   -           ",
"--  --          ",
" ------         ",
"    --          ",
"    -           "};


/* XPM */
static gchar *tb_copy_xpm[]={
"16 16 4 1",
" 	c None",
".	c #000000",
"-	c #FF0000",
"!	c #FFFFFF",
"    .........   ",
"    .!!!!!!!.   ",
"    .!!!!!!!.   ",
"    .!!.........",
"    .!!.!!!!!!!.",
"    .!!.!!!!!!!.",
"    .!!.!!!!!!!.",
"    .!!.!!!!!!!.",
"-   .!!.!!!!!!!.",
"-   .!!.!!!!!!!.",
"-   ....!!!!!!!.",
"-  -   .!!!!!!!.",
"-- --  .!!!!!!!.",
" ----- .........",
"   --           ",
"   -            "};


/* XPM */
static gchar *tb_paste_xpm[]={
"16 16 5 1",
" 	c None",
".	c #000000",
"*	c #C0C0C0",
"=	c #808080",
"!	c #FFFFFF",
"                ",
"     .........  ",
"     .!!!!!!!.  ",
"     .!!!!!!!.  ",
"  ....!!!!!!!.  ",
"  .!!=!!!!!!!.  ",
"  .!!=!!!!!!!.  ",
"  .!!=====!!!.  ",
"  .!!!*!!=!!!.  ",
"  .!!!!*!=!!!.  ",
"  .!!!!!*=!!!.  ",
"  .!!!!!!=....  ",
"  .!!!!!!!.     ",
"  .!!!!!!!.     ",
"  .........     ",
"                "};


/* XPM */
static gchar *tb_delete_xpm[]={
"16 16 2 1",
" 	c None",
",	c #0000FF",
"                ",
"                ",
"                ",
"             ,, ",
" ,,,,       ,  ,",
"   ,,,,,    ,  ,",
"     ,,,,    ,, ",
"        ,,,,,   ",
"      ,,,, ,,   ",
"   ,,,,,    ,,, ",
" ,,,,,     ,   ,",
"           ,   ,",
"            ,,, ",
"                ",
"                ",
"                "};


/* XPM */
static gchar *tb_undo_xpm[]={
"16 16 2 1",
" 	c None",
"-	c #FF0000",
"                ",
"      ---       ",
"    -------     ",
"   ---   ---    ",
"   --     --    ",
"  --       --   ",
"  --       --   ",
"  --       --   ",
"  --       --   ",
"  --       --   ",
"  --       --   ",
"  --       --   ",
"  --     ------ ",
"  --      ----  ",
"  --       --   ",
"  --            "};


/* XPM */
static gchar *tb_redo_xpm[]={
"16 16 2 1",
" 	c None",
",	c #0000FF",
"            ,,  ",
"   ,,       ,,  ",
"  ,,,,      ,,  ",
" ,,,,,,     ,,  ",
"   ,,       ,,  ",
"   ,,       ,,  ",
"   ,,       ,,  ",
"   ,,       ,,  ",
"   ,,       ,,  ",
"   ,,       ,,  ",
"   ,,       ,,  ",
"    ,,     ,,   ",
"    ,,,   ,,,   ",
"     ,,,,,,,    ",
"       ,,,      ",
"                "};


/* XPM */
static gchar *tb_find_xpm[]={
"16 16 5 1",
" 	c None",
".	c #000000",
"$	c #000080",
",	c #0000FF",
"!	c #FFFFFF",
"         ....   ",
"        .    .  ",
"       .    !!. ",
"      .      !!.",
"      .       !.",
"      .       !.",
"      .        .",
"      ,.      . ",
"     ,,$.    .  ",
"    ,,$!,....   ",
"   ,,$!,        ",
"  ,,$!,         ",
" ,,$!,          ",
",,$!,           ",
" $!,            ",
"  ,             "};


/* XPM */
static gchar *tb_replace_xpm[]={
"16 16 5 1",
" 	c None",
".	c #000000",
"-	c #FF0000",
",	c #0000FF",
"!	c #FFFFFF",
"                ",
"   -----        ",
"       --       ",
"  -     -       ",
" ---  -----     ",
"-----  ---      ",
"  -     -  ...  ",
"  --      .   . ",
"   ----- .   !!.",
"         .    !.",
"         .     .",
"         ,.   . ",
"        ,,,...  ",
"       ,,,      ",
"      ,,,       ",
"       ,        "};


ToolBar toolbar_items[]={
/*  0 */ {N_("New"),       tb_new_xpm,    command_new,     NULL,NULL},
/*  1 */ {N_("Open"),      tb_open_xpm,   command_open,    NULL,NULL},
/*  2 */ {N_("Save"),      tb_save_xpm,   command_save,    NULL,NULL},
/*  3 */ {NULL,            NULL,          NULL,            NULL,NULL},
/*  4 */ {N_("Properties"),tb_prop_xpm,   command_property,NULL,NULL},
/*  5 */ {NULL,            NULL,          NULL,            NULL,NULL},
#ifdef USE_GDKPIXBUF
/*  6 */ {N_("Print"),     tb_print_xpm,  command_print,   NULL,NULL},
/*  7 */ {NULL,            NULL,          NULL,            NULL,NULL},
#endif
/*  8 */ {N_("Cut"),       tb_cut_xpm,    command_cut,     NULL,NULL},
/*  9 */ {N_("Copy"),      tb_copy_xpm,   command_copy,    NULL,NULL},
/* 10 */ {N_("Paste"),     tb_paste_xpm,  command_paste,   NULL,NULL},
/* 11 */ {N_("Delete"),    tb_delete_xpm, command_delete,  NULL,NULL},
/* 12 */ {NULL,            NULL,          NULL,            NULL,NULL},
/* 13 */ {N_("Undo"),      tb_undo_xpm,   command_undo,    NULL,NULL},
/* 14 */ {N_("Redo"),      tb_redo_xpm,   command_redo,    NULL,NULL},
/* 15 */ {NULL,            NULL,          NULL,            NULL,NULL},
/* 16 */ {N_("Find"),      tb_find_xpm,   command_find,    NULL,NULL},
/* 17 */ {N_("Replace"),   tb_replace_xpm,command_replace, NULL,NULL},
/* 18 */ {(gpointer)-1,    NULL,          NULL,            NULL,NULL}};
